<?php

namespace Litecms\Marketing\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Marketing\Models\Campaign;

class CampaignPolicy
{


    /**
     * Determine if the given user can view the campaign.
     *
     * @param UserPolicyInterface $authUser
     * @param Campaign $campaign
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Campaign $campaign)
    {
        if ($authUser->canDo('marketing.campaign.view') && $authUser->isAdmin()) {
            return true;
        }

        return $campaign->user_id == user_id() && $campaign->user_type == user_type();
    }

    /**
     * Determine if the given user can create a campaign.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('marketing.campaign.create');
    }

    /**
     * Determine if the given user can update the given campaign.
     *
     * @param UserPolicyInterface $authUser
     * @param Campaign $campaign
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Campaign $campaign)
    {
        if ($authUser->canDo('marketing.campaign.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $campaign->user_id == user_id() && $campaign->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given campaign.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Campaign $campaign)
    {
        return $campaign->user_id == user_id() && $campaign->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given campaign.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Campaign $campaign)
    {
        if ($authUser->canDo('marketing.campaign.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given campaign.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Campaign $campaign)
    {
        if ($authUser->canDo('marketing.campaign.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
